@@ -8,8 +8,11 @@ Perl::Dist::Bootstrap - A Perl distribution for building Perl distributions
 
 =head1 DESCRIPTION
 
-Bootstrap Perl is a subclass and variant of Strawberry Perl that 
-also installs a number of additional modules that are
+Bootstrap Perl is a subclass and variant of Strawberry Perl that installs
+into a different directory (C:\bootperl) than Strawberry Perl so that
+it won't be "in the way" when building Strawberry and other Perls.
+
+It also comes prepackaged with a number of additional modules that are
 dependencies of Perl::Dist and Perl::Dist::WiX.
 
 =cut
@@ -21,8 +24,10 @@ use parent                  qw( Perl::Dist::Strawberry );
 use File::Spec::Functions   qw( catfile catdir         );
 use File::ShareDir          qw();
 
-our $VERSION = '2.10_10';
-$VERSION =~ s/_//ms;
+our $VERSION = '2.01';
+$VERSION = eval $VERSION;
+
+
 
 
 
@@ -32,27 +37,23 @@ $VERSION =~ s/_//ms;
 # Apply some default paths
 sub new {
 
-	if ($Perl::Dist::Strawberry::VERSION < 2.1010) {
+	if ($Perl::Dist::Strawberry::VERSION < 2.00_02) {
 		PDWiX->throw('Perl::Dist::Strawberry version is not high enough.')
 	}
-	if ($Perl::Dist::WiX::VERSION < 1.200100) {
-		PDWiX->throw('Perl::Dist::WiX version is not high enough.')
-	}
 
 	shift->SUPER::new(
 		app_id            => 'bootperl',
 		app_name          => 'Bootstrap Perl',
 		app_publisher     => 'Vanilla Perl Project',
 		app_publisher_url => 'http://vanillaperl.org/',
-		image_dir         => 'C:\\strawberry',
-		perl_version      => '5121',
+		image_dir         => 'C:\\bootperl',
 
 		# Tasks to complete to create Bootstrap
 		tasklist => [
 			'final_initialization',
-			'initialize_nomsm',
 			'install_c_toolchain',
 			'install_strawberry_c_toolchain',
+			'install_c_libraries',
 			'install_strawberry_c_libraries',
 			'install_perl',
 			'install_perl_toolchain',
@@ -61,40 +62,40 @@ sub new {
 			'install_strawberry_modules_2',
 			'install_strawberry_modules_3',
 			'install_strawberry_modules_4',
-			'install_strawberry_modules_5',
 			'install_bootstrap_modules_1',
 			'install_bootstrap_modules_2',
 			'install_win32_extras',
 			'install_strawberry_extras',
+			'install_portable',
 			'remove_waste',
+			'add_forgotten_files',
 			'create_distribution_list',
 			'regenerate_fragments',
 			'write',
 		],
 
-		# Build msi version only. Do not create a merge module.
+		# Build msi version only.
 		msi               => 1,
 		zip               => 0,
-		msm               => 0,
 
 		@_,
 	);
 }
 
-
-
 # Lazily default the file name
 # Supports building multiple versions of Perl.
 sub output_base_filename {
 	$_[0]->{output_base_filename} or
-	'bootstrap-perl' 
-	. '-' . $_[0]->perl_version_human() 
-	. '.' . $_[0]->build_number()
-	. ($_[0]->beta_number() ? '-beta-' . $_[0]->beta_number : '');
+	'bootstrap-perl-' . $_[0]->perl_version_human 
+	. '.' . $_[0]->build_number
+	. ($_[0]->beta_number ? '-beta-' . $_[0]->beta_number : '');
 }
 
 
 
+
+
+
 #####################################################################
 # Customisations for Perl assets
 
@@ -114,8 +115,6 @@ sub patch_include_path {
 	];
 }
 
-
-
 sub install_bootstrap_modules_1 {
 	my $self = shift;
 	my $share = File::ShareDir::dist_dir('Perl-Dist-Strawberry');
@@ -128,7 +127,7 @@ sub install_bootstrap_modules_1 {
 		buildpl_param => ['--installdirs', 'vendor'],
 	);
 
-	# Install everything required for Perl::Dist::WiX itself
+	# Install Perl::Dist and everything required for Perl::Dist::WiX itself
 	$self->install_modules( qw(
 		File::Copy::Recursive
 		Class::Inspector
@@ -143,9 +142,8 @@ sub install_bootstrap_modules_1 {
 		Test::LongString
 		Module::ScanDeps
 		Module::Install
-		Module::Install::AuthorTests
-		Module::Install::PerlTar
 		Tie::Slurp
+		File::Slurp
 		File::IgnoreReadonly
 		Portable::Dist
 		List::MoreUtils
@@ -153,18 +151,18 @@ sub install_bootstrap_modules_1 {
 		Template
 	) );
 	
-	# Data::UUID needs to have a temp directory set that will
-	# exist in the installation image.
+	# Perl::Dist does not pass tests if offline.
+	# $self->install_module( name => 'Perl::Dist', force => !! $self->offline );
+
+	# Data::UUID needs to have a temp directory set.
 	{
-		local $ENV{'TMPDIR'} = $self->image_dir();
+		local $ENV{'TMPDIR'} = $self->image_dir;
 		$self->install_module( name => 'Data::UUID', );
 	}
 
 	return 1;
 }
 
-
-
 sub install_bootstrap_modules_2 {
 	my $self = shift;
 	
@@ -178,6 +176,7 @@ sub install_bootstrap_modules_2 {
 		Exception::Class
 		Test::UseAllModules
 		ExtUtils::Depends
+		Task::Weaken
 		B::Utils
 		PadWalker
 		Data::Dump::Streamer
@@ -191,30 +190,25 @@ sub install_bootstrap_modules_2 {
 		Scope::Guard
 		Devel::GlobalDestruction
 		Sub::Name
-		Try::Tiny
+		Test::Exception
 		Class::MOP
+		Try::Tiny
 		Moose
 		MooseX::AttributeHelpers
 		File::List::Object
 		Params::Validate
 		MooseX::Singleton
-		MooseX::NonMoose
 		Variable::Magic
 		B::Hooks::EndOfScope
-		Sub::Identify
 		namespace::clean
 		Carp::Clan
 		MooseX::Types
-		Path::Class
-		MooseX::Types::Path::Class
-		URI::FromHash
-		Test::use::ok
-		MooseX::Types::URI
 		Email::Date::Format
 		Date::Format
 		Test::Pod
 		Mail::Address
 		MIME::Types
+		MooseX::NonMoose
 	) );
 	# The current version of MIME::Types causes
 	# MIME::Lite to fail tests.
@@ -223,78 +217,22 @@ sub install_bootstrap_modules_2 {
 		force => 1,
 	);
 	$self->install_modules( qw(
-		Clone
-		Digest::CRC
 		WiX3
 		CPAN::Mini
 		CPAN::Mini::Devel
 	) );
 
-	# Since we're using the "fake" Alien::WiX, we have to force here.
-	$self->install_distribution(
-		name     => 'CSJEWELL/Perl-Dist-WiX-1.200.tar.gz',
-		mod_name => 'Perl::Dist::WiX',
-		force    => 1,
-		makefilepl_param => ['INSTALLDIRS=vendor'],
-	);
+#	$self->install_module(
+#		name => 'Perl::Dist::WiX',
+#		force => 1,
+#	);
+#	$self->install_distribution(
+#		name     => 'CSJEWELL/Perl-Dist-WiX-1.090_103.tar.gz',
+#		mod_name => 'Perl::Dist::WiX',
+#		force    => 1,
+#		makefilepl_param => ['INSTALLDIRS=vendor'],
+#	);
 
-	# Install stuff required to test Perl::Dist::Strawberry and 
-	# Perl::Dist::WiX in author mode.
-	$self->install_module(
-		name => 'File::Finder',
-		force => 1,	# fails tests.
-	);
-	$self->install_distribution(
-		name     => 'GAM/Test-CheckChanges-0.14.tar.gz', # CPAN cannot extract.
-		mod_name => 'Test::CheckChanges',
-		force    => 1,
-		makefilepl_param => ['INSTALLDIRS=vendor'],
-	);
-	$self->install_modules( qw(
-		File::Find::Rule::Perl
-		Test::Object
-		Hook::LexWrap
-		Test::SubCalls
-	) );
-	$self->install_distribution(
-		name     => 'ADAMK/PPI-1.211_01.tar.gz',
-		mod_name => 'PPI',
-		makefilepl_param => ['INSTALLDIRS=vendor'],
-	);		
-	$self->install_modules( qw(
-		Module::Manifest
-		Module::Info
-		Perl::Tidy
-		PPIx::Regexp
-		Email::Address
-		B::Keywords
-		Pod::Spell
-		Pod::Spell::CommonMistakes
-		String::Format
-		PPIx::Utilities
-		Config::Tiny
-		Devel::Symdump
-		Pod::Coverage
-	) );
-	$self->install_distribution(
-		name     => 'THALJEF/Perl-Critic-1.105_03.tar.gz',
-		mod_name => 'Perl::Critic',
-		buildpl_param => ['--installdirs', 'vendor'],
-	);
-	$self->install_modules( qw(
-		Perl::MinimumVersion
-		Perl::Critic::More
-		Test::Perl::Critic
-		Test::Pod::Coverage
-		Test::MinimumVersion
-		Test::Fixme
-		Test::HasVersion
-		Test::CPAN::Meta
-		Test::DistManifest
-		Test::Prereq
-		Test::Pod::Spelling::CommonMistakes
-	) );
-	
 	return 1;
 }
 
@@ -323,9 +261,7 @@ Curtis Jewell E<lt>csjewell@cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright 2007 - 2009 Adam Kennedy.  
-
-Copyright 2009 - 2010 Curtis Jewell.
+Copyright 2007 - 2009 Adam Kennedy.  Copyright 2009 Curtis Jewell.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
